@@ -1,24 +1,14 @@
 # Dropbox storage class for Django pluggable storage system.
 # Author: Anthony Monthe <anthony.monthe@gmail.com>
 # License: BSD
-#
-# Usage:
-#
-# Add below to settings.py:
-# DROPBOX_ROOT_PATH = '/dir/'
-# DROPBOX_OAUTH2_TOKEN = 'YourOauthToken'
-# DROPBOX_APP_KEY = 'YourAppKey'
-# DROPBOX_APP_SECRET = 'YourAppSecret``
-# DROPBOX_OAUTH2_REFRESH_TOKEN = 'YourOauthRefreshToken'
-
 
+import warnings
 from io import BytesIO
 from shutil import copyfileobj
 from tempfile import SpooledTemporaryFile
 
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.base import File
-from django.core.files.storage import Storage
 from django.utils._os import safe_join
 from django.utils.deconstruct import deconstructible
 from dropbox import Dropbox
@@ -28,18 +18,28 @@ from dropbox.files import FolderMetadata
 from dropbox.files import UploadSessionCursor
 from dropbox.files import WriteMode
 
+from storages.base import BaseStorage
 from storages.utils import get_available_overwrite_name
 from storages.utils import setting
 
 _DEFAULT_TIMEOUT = 100
-_DEFAULT_MODE = 'add'
+_DEFAULT_MODE = "add"
 
 
-class DropBoxStorageException(Exception):
+class DropboxStorageException(Exception):
     pass
 
 
-class DropBoxFile(File):
+DropBoxStorageException = DropboxStorageException
+
+
+def removeprefix(prefix, name):
+    if name.startswith(prefix):
+        name = name[len(prefix) :]
+    return name
+
+
+class DropboxFile(File):
     def __init__(self, name, storage):
         self.name = name
         self._storage = storage
@@ -50,16 +50,16 @@ class DropBoxFile(File):
             self._file = SpooledTemporaryFile()
             # As dropbox==9.3.0, the client returns a tuple
             # (dropbox.files.FileMetadata, requests.models.Response)
-            file_metadata, response = \
-                self._storage.client.files_download(self.name)
+            file_metadata, response = self._storage.client.files_download(self.name)
             if response.status_code == 200:
                 with BytesIO(response.content) as file_content:
                     copyfileobj(file_content, self._file)
             else:
                 # JIC the exception isn't catched by the dropbox client
-                raise DropBoxStorageException(
-                    "Dropbox server returned a {} response when accessing {}"
-                    .format(response.status_code, self.name)
+                raise DropboxStorageException(
+                    "Dropbox server returned a {} response when accessing {}".format(
+                        response.status_code, self.name
+                    )
                 )
             self._file.seek(0)
         return self._file
@@ -70,31 +70,20 @@ class DropBoxFile(File):
     file = property(_get_file, _set_file)
 
 
+DropBoxFile = DropboxFile
+
+
 @deconstructible
-class DropBoxStorage(Storage):
-    """DropBox Storage class for Django pluggable storage system."""
-    location = setting('DROPBOX_ROOT_PATH', '/')
-    oauth2_access_token = setting('DROPBOX_OAUTH2_TOKEN')
-    app_key = setting('DROPBOX_APP_KEY')
-    app_secret = setting('DROPBOX_APP_SECRET')
-    oauth2_refresh_token = setting('DROPBOX_OAUTH2_REFRESH_TOKEN')
-    timeout = setting('DROPBOX_TIMEOUT', _DEFAULT_TIMEOUT)
-    write_mode = setting('DROPBOX_WRITE_MODE', _DEFAULT_MODE)
+class DropboxStorage(BaseStorage):
+    """Dropbox Storage class for Django pluggable storage system."""
 
     CHUNK_SIZE = 4 * 1024 * 1024
 
-    def __init__(
-        self,
-        oauth2_access_token=oauth2_access_token,
-        root_path=location,
-        timeout=timeout,
-        write_mode=write_mode,
-        app_key=app_key,
-        app_secret=app_secret,
-        oauth2_refresh_token=oauth2_refresh_token,
-    ):
-        if oauth2_access_token is None and not all(
-            [app_key, app_secret, oauth2_refresh_token]
+    def __init__(self, oauth2_access_token=None, **settings):
+        super().__init__(oauth2_access_token=oauth2_access_token, **settings)
+
+        if self.oauth2_access_token is None and not all(
+            [self.app_key, self.app_secret, self.oauth2_refresh_token]
         ):
             raise ImproperlyConfigured(
                 "You must configure an auth token at"
@@ -103,20 +92,39 @@ class DropBoxStorage(Storage):
                 "'setting.DROPBOX_APP_SECRET' "
                 "and 'setting.DROPBOX_OAUTH2_REFRESH_TOKEN'."
             )
-        self.root_path = root_path
-        self.write_mode = write_mode
         self.client = Dropbox(
-            oauth2_access_token,
-            app_key=app_key,
-            app_secret=app_secret,
-            oauth2_refresh_token=oauth2_refresh_token,
-            timeout=timeout,
+            self.oauth2_access_token,
+            app_key=self.app_key,
+            app_secret=self.app_secret,
+            oauth2_refresh_token=self.oauth2_refresh_token,
+            timeout=self.timeout,
         )
 
+        # Backwards compat
+        if hasattr(self, "location"):
+            warnings.warn(
+                "Setting `root_path` with name `location` is deprecated and will be "
+                "removed in a future version of django-storages. Please update the "
+                "name from `location` to `root_path`",
+                DeprecationWarning,
+            )
+            self.root_path = self.location
+
+    def get_default_settings(self):
+        return {
+            "root_path": setting("DROPBOX_ROOT_PATH", "/"),
+            "oauth2_access_token": setting("DROPBOX_OAUTH2_TOKEN"),
+            "app_key": setting("DROPBOX_APP_KEY"),
+            "app_secret": setting("DROPBOX_APP_SECRET"),
+            "oauth2_refresh_token": setting("DROPBOX_OAUTH2_REFRESH_TOKEN"),
+            "timeout": setting("DROPBOX_TIMEOUT", _DEFAULT_TIMEOUT),
+            "write_mode": setting("DROPBOX_WRITE_MODE", _DEFAULT_MODE),
+        }
+
     def _full_path(self, name):
-        if name == '/':
-            name = ''
-        return safe_join(self.root_path, name).replace('\\', '/')
+        if name == "/":
+            name = ""
+        return safe_join(self.root_path, name).replace("\\", "/")
 
     def delete(self, name):
         self.client.files_delete(self._full_path(name))
@@ -131,8 +139,8 @@ class DropBoxStorage(Storage):
         directories, files = [], []
         full_path = self._full_path(path)
 
-        if full_path == '/':
-            full_path = ''
+        if full_path == "/":
+            full_path = ""
 
         metadata = self.client.files_list_folder(full_path)
         for entry in metadata.entries:
@@ -146,14 +154,6 @@ class DropBoxStorage(Storage):
         metadata = self.client.files_get_metadata(self._full_path(name))
         return metadata.size
 
-    def modified_time(self, name):
-        metadata = self.client.files_get_metadata(self._full_path(name))
-        return metadata.server_modified
-
-    def accessed_time(self, name):
-        metadata = self.client.files_get_metadata(self._full_path(name))
-        return metadata.client_modified
-
     def url(self, name):
         try:
             media = self.client.files_get_temporary_link(self._full_path(name))
@@ -161,28 +161,30 @@ class DropBoxStorage(Storage):
         except ApiError:
             return None
 
-    def _open(self, name, mode='rb'):
-        remote_file = DropBoxFile(self._full_path(name), self)
+    def _open(self, name, mode="rb"):
+        remote_file = DropboxFile(self._full_path(name), self)
         return remote_file
 
     def _save(self, name, content):
         content.open()
         if content.size <= self.CHUNK_SIZE:
-            self.client.files_upload(content.read(), self._full_path(name), mode=WriteMode(self.write_mode))
+            self.client.files_upload(
+                content.read(), self._full_path(name), mode=WriteMode(self.write_mode)
+            )
         else:
             self._chunked_upload(content, self._full_path(name))
         content.close()
-        # .save() validates the filename isn't absolute but Dropbox requires an absolute filename.
-        # Work with the absolute name internally but strip it off before passing up-the-chain.
-        return name.lstrip(self.root_path)
+        # .save() validates the filename isn't absolute but Dropbox requires an
+        # absolute filename.  Work with the absolute name internally but strip it
+        # off before passing up-the-chain.
+        return removeprefix(self.root_path, name).lstrip("/")
 
     def _chunked_upload(self, content, dest_path):
         upload_session = self.client.files_upload_session_start(
             content.read(self.CHUNK_SIZE)
         )
         cursor = UploadSessionCursor(
-            session_id=upload_session.session_id,
-            offset=content.tell()
+            session_id=upload_session.session_id, offset=content.tell()
         )
         commit = CommitInfo(path=dest_path, mode=WriteMode(self.write_mode))
 
@@ -200,6 +202,9 @@ class DropBoxStorage(Storage):
     def get_available_name(self, name, max_length=None):
         """Overwrite existing file with the same name."""
         name = self._full_path(name)
-        if self.write_mode == 'overwrite':
+        if self.write_mode == "overwrite":
             return get_available_overwrite_name(name, max_length)
         return super().get_available_name(name, max_length)
+
+
+DropBoxStorage = DropboxStorage
