@@ -5,6 +5,7 @@ import posixpath
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.exceptions import SuspiciousFileOperation
+from django.core.files.utils import FileProxyMixin
 from django.utils.encoding import force_bytes
 
 
@@ -34,23 +35,23 @@ def clean_name(name):
     Normalize the name.
 
     Includes cleaning up Windows style paths, ensuring an ending trailing slash,
-    and coercing from pathlib.Path.
+    and coercing from pathlib.PurePath.
     """
-    if isinstance(name, pathlib.Path):
+    if isinstance(name, pathlib.PurePath):
         name = str(name)
 
     # Normalize Windows style paths
-    clean_name = posixpath.normpath(name).replace('\\', '/')
+    clean_name = posixpath.normpath(name).replace("\\", "/")
 
     # os.path.normpath() can strip trailing slashes so we implement
     # a workaround here.
-    if name.endswith('/') and not clean_name.endswith('/'):
+    if name.endswith("/") and not clean_name.endswith("/"):
         # Add a trailing slash as it was stripped.
-        clean_name += '/'
+        clean_name += "/"
 
     # Given an empty string, os.path.normpath() will return ., which we don't want
-    if clean_name == '.':
-        clean_name = ''
+    if clean_name == ".":
+        clean_name = ""
 
     return clean_name
 
@@ -69,34 +70,38 @@ def safe_join(base, *paths):
     sensitive operation.
     """
     base_path = base
-    base_path = base_path.rstrip('/')
-    paths = [p for p in paths]
+    base_path = base_path.rstrip("/")
+    paths = list(paths)
 
-    final_path = base_path + '/'
+    final_path = base_path + "/"
     for path in paths:
         _final_path = posixpath.normpath(posixpath.join(final_path, path))
         # posixpath.normpath() strips the trailing /. Add it back.
-        if path.endswith('/') or _final_path + '/' == final_path:
-            _final_path += '/'
+        if path.endswith("/") or _final_path + "/" == final_path:
+            _final_path += "/"
         final_path = _final_path
     if final_path == base_path:
-        final_path += '/'
+        final_path += "/"
 
     # Ensure final_path starts with base_path and that the next character after
     # the base path is /.
     base_path_len = len(base_path)
-    if (not final_path.startswith(base_path) or final_path[base_path_len] != '/'):
-        raise ValueError('the joined path is located outside of the base path'
-                         ' component')
+    if not final_path.startswith(base_path) or final_path[base_path_len] != "/":
+        raise ValueError(
+            "the joined path is located outside of the base path component"
+        )
 
-    return final_path.lstrip('/')
+    return final_path.lstrip("/")
 
 
 def check_location(storage):
-    if storage.location.startswith('/'):
-        correct = storage.location.lstrip('/')
+    if storage.location.startswith("/"):
+        correct = storage.location.lstrip("/")
         raise ImproperlyConfigured(
-            "{}.location cannot begin with a leading slash. Found '{}'. Use '{}' instead.".format(
+            (
+                "{}.location cannot begin with a leading slash. Found '{}'. Use '{}' "
+                "instead."
+            ).format(
                 storage.__class__.__name__,
                 storage.location,
                 correct,
@@ -104,17 +109,6 @@ def check_location(storage):
         )
 
 
-def lookup_env(names):
-    """
-    Look up for names in environment. Returns the first element
-    found.
-    """
-    for name in names:
-        value = os.environ.get(name)
-        if value:
-            return value
-
-
 def get_available_overwrite_name(name, max_length):
     if max_length is None or len(name) <= max_length:
         return name
@@ -128,11 +122,40 @@ def get_available_overwrite_name(name, max_length):
     if not file_root:
         raise SuspiciousFileOperation(
             'Storage tried to truncate away entire filename "%s". '
-            'Please make sure that the corresponding file field '
+            "Please make sure that the corresponding file field "
             'allows sufficient "max_length".' % name
         )
     return os.path.join(dir_name, "{}{}".format(file_root, file_ext))
 
 
 def is_seekable(file_object):
-    return not hasattr(file_object, 'seekable') or file_object.seekable()
+    return not hasattr(file_object, "seekable") or file_object.seekable()
+
+
+class ReadBytesWrapper(FileProxyMixin):
+    """
+    A wrapper for a file-like object, that makes read() always returns bytes.
+    """
+
+    def __init__(self, file, encoding=None):
+        """
+        :param file: The file-like object to wrap.
+        :param encoding: Specify the encoding to use when file.read() returns strings.
+            If not provided will default to file.encoding, of if that's not available,
+            to utf-8.
+        """
+        self.file = file
+        self._encoding = encoding or getattr(file, "encoding", None) or "utf-8"
+
+    def read(self, *args, **kwargs):
+        content = self.file.read(*args, **kwargs)
+
+        if not isinstance(content, bytes):
+            content = content.encode(self._encoding)
+        return content
+
+    def close(self):
+        self.file.close()
+
+    def readable(self):
+        return True
